@@ -16,7 +16,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 #include <scheduler.h>
@@ -41,11 +41,7 @@ public:
     }
 
     void start() override {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
         QMetaObject::invokeMethod(this,  &DummyIndexingJob::finish, Qt::QueuedConnection);
-#else
-        QMetaObject::invokeMethod(this, "finish", Qt::QueuedConnection);
-#endif
 
     }
 
