@@ -16,20 +16,19 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
+#include <xapian.h>
+
 #include "contactquery.h"
 #include "resultiterator_p.h"
-#include "xapian.h"
 #include "akonadi_search_pim_debug.h"
 
-
 #include <QList>
 #include <QDebug>
 #include <QStandardPaths>
-
 #include <QFile>
 
 using namespace Akonadi::Search::PIM;
