@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,16 +16,19 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
+
+#include <xapian.h>
+
 #include "indexeditems.h"
 #include "akonadi_search_pim_debug.h"
+
 #include <QStandardPaths>
 #include <QHash>
 #include <QDir>
 #include <AkonadiCore/ServerManager>
-#include <xapian.h>
 
 using namespace Akonadi::Search::PIM;
 
@@ -59,7 +62,7 @@ QString IndexedItemsPrivate::dbPath(const QString &dbName) const
         return cachedPath;
     }
     if (!m_overridePrefixPath.isEmpty()) {
-        const QString path = QString::fromLatin1("%1/%2/").arg(m_overridePrefixPath, dbName);
+        const QString path = QStringLiteral("%1/%2/").arg(m_overridePrefixPath, dbName);
         m_cachePath.insert(dbName, path);
         return path;
     }
@@ -136,7 +139,7 @@ qlonglong IndexedItemsPrivate::indexedItemsInDatabase(const std::string &term, c
 
 qlonglong IndexedItemsPrivate::indexedItems(const qlonglong id)
 {
-    const std::string term = QString::fromLatin1("C%1").arg(id).toStdString();
+    const std::string term = QStringLiteral("C%1").arg(id).toStdString();
     return indexedItemsInDatabase(term, emailIndexingPath())
            + indexedItemsInDatabase(term, contactIndexingPath())
            + indexedItemsInDatabase(term, akonotesIndexingPath())
@@ -152,7 +155,7 @@ void IndexedItemsPrivate::findIndexedInDatabase(QSet<Akonadi::Item::Id> &indexed
         qCCritical(AKONADI_SEARCH_PIM_LOG) << "Failed to open database" << dbPath << ":" << QString::fromStdString(e.get_msg());
         return;
     }
-    const std::string term = QString::fromLatin1("C%1").arg(collectionId).toStdString();
+    const std::string term = QStringLiteral("C%1").arg(collectionId).toStdString();
     Xapian::Query query(term);
     Xapian::Enquire enquire(db);
     enquire.set_query(query);
