@@ -16,7 +16,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -82,7 +82,7 @@ void App::main()
 void App::slotItemsReceived(const Akonadi::Item::List &list)
 {
     qDebug() << list.size();
-    Q_FOREACH (const Akonadi::Item &item, list) {
+    for (const Akonadi::Item &item : list) {
         qDebug() << item.id() << item.mimeType();
     }
 }
