@@ -18,7 +18,7 @@
  */
 
 #include "pimcontactsrunnerconfig.h"
-
+#include <kconfigwidgets_version.h>
 #include <QCheckBox>
 #include <QVBoxLayout>
 #include <KLocalizedString>
@@ -45,7 +45,11 @@ PIMContactsRunnerConfig::PIMContactsRunnerConfig(QWidget *parent, const QVariant
 
 void PIMContactsRunnerConfig::configChanged()
 {
+#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
     Q_EMIT changed();
+#else
+    Q_EMIT markAsChanged();
+#endif
 }
 
 void PIMContactsRunnerConfig::load()
